@@ -58,7 +58,7 @@ class NativeHWManagementService(Service):
     @keyword
     @is_connected
     def hw_management_service_get_logging_endpoint(self, param_dict, **kwargs):
-        return self._grpc_helper(self.stub.GetLoggingEndpoint, hw_pb2.Uuid, param_dict)
+        return self._grpc_helper(self.stub.GetLoggingEndpoint, hw_pb2.HardwareID, param_dict)
 
     # rpc SetMsgBusEndpoint(SetMsgBusEndpointRequest) returns(SetRemoteEndpointResponse);
     @keyword
